var NAVTREEINDEX17 =
{
"matrix__vector_8cpp.html":[7,0,2,0,22],
"matrix__vector_8cpp.html#a00412d857cf1280ac59bac80061ccf0a":[7,0,2,0,22,7],
"matrix__vector_8cpp.html#a0fa2d0d0ec97d6cd1192a960d64d92ec":[7,0,2,0,22,6],
"matrix__vector_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,22,3],
"matrix__vector_8cpp.html#aacca06eadc801980b85316ba3e9a018b":[7,0,2,0,22,5],
"matrix__vector_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,22,2],
"matrix__vector_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,22,4],
"matrix__vector_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,22,0],
"matrix__vector_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,22,1],
"matrix__vector_8cpp_source.html":[7,0,2,0,22],
"matrix__vector__int_8cpp.html":[7,0,2,0,23],
"matrix__vector__int_8cpp.html#a50272a6ac2b783e6ce4d7b4d646fc70f":[7,0,2,0,23,3],
"matrix__vector__int_8cpp.html#abb00dc6bc0c69a5f9a07f1e5ea24eb93":[7,0,2,0,23,5],
"matrix__vector__int_8cpp.html#ac402576cb4f901caab768016d2131538":[7,0,2,0,23,2],
"matrix__vector__int_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,23,4],
"matrix__vector__int_8cpp.html#ae68ad112f7ea64cf94b147ec7625086e":[7,0,2,0,23,6],
"matrix__vector__int_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,2,0,23,0],
"matrix__vector__int_8cpp.html#afebc249681af56fdd45860b32ed34b4e":[7,0,2,0,23,1],
"matrix__vector__int_8cpp_source.html":[7,0,2,0,23],
"maxmin_8hpp.html":[7,0,3,4,23],
"maxmin_8hpp.html#a3174c1f0846b0f4801e203b2048f12de":[7,0,3,4,23,1],
"maxmin_8hpp.html#a5057d08504cc799dd77dfd596499bffc":[7,0,3,4,23,5],
"maxmin_8hpp.html#a554dda7695e02807c9f56029c192bc73":[7,0,3,4,23,2],
"maxmin_8hpp.html#acae51ad7f1972ca14eeedc59f08b12b8":[7,0,3,4,23,6],
"maxmin_8hpp.html#adfd5b21910a692a78c547b22b9157c2e":[7,0,3,4,23,0],
"maxmin_8hpp.html#ae0a4445a6d0f1d75e7157cdc23239027":[7,0,3,4,23,3],
"maxmin_8hpp.html#ae602a9321e77bce6adb827a2514de278":[7,0,3,4,23,4],
"maxmin_8hpp_source.html":[7,0,3,4,23],
"mem__handle_8hpp.html":[7,0,3,0,2],
"mem__handle_8hpp.html#a0238c5401fc7e05c3641b1ad5e872458":[7,0,3,0,2,1],
"mem__handle_8hpp.html#a1361a53026515c9e7b7b57548c66a500":[7,0,3,0,2,2],
"mem__handle_8hpp.html#ac90bff9578adec99b7f6a67cca6d5c80":[7,0,3,0,2,3],
"mem__handle_8hpp_source.html":[7,0,3,0,2],
"memory_8hpp.html":[7,0,3,0,3],
"memory_8hpp.html#a06bdedb2bc72dc1922cada91e9bbbd61":[7,0,3,0,3,10],
"memory_8hpp.html#a06e699859e0bf8a0dae58fa9814abf45":[7,0,3,0,3,2],
"memory_8hpp.html#a125b816cda53b54723572f319c096e68":[7,0,3,0,3,11],
"memory_8hpp.html#a1499f19634964e2c7c8aeeefc6206126":[7,0,3,0,3,7],
"memory_8hpp.html#a3707340b27c535438e213e3879b0f0a4":[7,0,3,0,3,5],
"memory_8hpp.html#a37a80732ade332cb8b1c0a17ed181b54":[7,0,3,0,3,3],
"memory_8hpp.html#a39a91fd7aa68ebf64bd7bfa409732ec0":[7,0,3,0,3,6],
"memory_8hpp.html#a3e08136f371bfae415d35f75a7c8639d":[7,0,3,0,3,13],
"memory_8hpp.html#a62854cfd6f04404b274f8ede36f63e2d":[7,0,3,0,3,8],
"memory_8hpp.html#a84e78df5ffd86afde0313ac849b0909a":[7,0,3,0,3,1],
"memory_8hpp.html#a8548a37535eac92e886cb183182b618f":[7,0,3,0,3,9],
"memory_8hpp.html#a87d41d517b3d0daca8b1536e15e6659d":[7,0,3,0,3,12],
"memory_8hpp.html#aa26c168242b4a7522b3a44db4f35d678":[7,0,3,0,3,4],
"memory_8hpp.html#af9f9cc6c50debc5b1d93e458d1fd392a":[7,0,3,0,3,0],
"memory_8hpp_source.html":[7,0,3,0,3],
"misc__operations_8hpp.html":[7,0,3,4,24],
"misc__operations_8hpp.html#a38ce3ce654d6a8606e3ff8c321a3383f":[7,0,3,4,24,0],
"misc__operations_8hpp_source.html":[7,0,3,4,24],
"mixed__precision__cg_8hpp.html":[7,0,3,4,25],
"mixed__precision__cg_8hpp.html#a727542f4624926e74ff52ea5c75d546f":[7,0,3,4,25,1],
"mixed__precision__cg_8hpp.html#ab5579a603f93ad9fb66d8ebc358d7d5a":[7,0,3,4,25,2],
"mixed__precision__cg_8hpp_source.html":[7,0,3,4,25],
"mtl4-with-viennacl_8cpp-example.html":[8,18],
"mtl4-with-viennacl_8cpp.html":[7,0,0,1,19],
"mtl4-with-viennacl_8cpp_source.html":[7,0,0,1,19],
"multithreaded_8cpp-example.html":[8,19],
"multithreaded_8cpp.html":[7,0,0,1,20],
"multithreaded_8cpp_source.html":[7,0,0,1,20],
"multithreaded__cg_8cpp.html":[7,0,0,1,21],
"multithreaded__cg_8cpp_source.html":[7,0,0,1,21],
"multithreaded_cg_8cpp-example.html":[8,20],
"namespacedetail.html":[5,0,0],
"namespacemembers.html":[5,1,0,9],
"namespacemembers.html":[5,1,0,20],
"namespacemembers.html":[5,1,0,13],
"namespacemembers.html":[5,1,0,11],
"namespacemembers.html":[5,1,0,8],
"namespacemembers.html":[5,1,0],
"namespacemembers.html":[5,1,0,0],
"namespacemembers.html":[5,1,0,14],
"namespacemembers.html":[5,1,0,1],
"namespacemembers.html":[5,1,0,2],
"namespacemembers.html":[5,1,0,3],
"namespacemembers.html":[5,1,0,7],
"namespacemembers.html":[5,1,0,4],
"namespacemembers.html":[5,1,0,5],
"namespacemembers.html":[5,1,0,6],
"namespacemembers.html":[5,1,0,10],
"namespacemembers.html":[5,1,0,12],
"namespacemembers.html":[5,1,0,15],
"namespacemembers.html":[5,1,0,16],
"namespacemembers.html":[5,1,0,17],
"namespacemembers.html":[5,1,0,21],
"namespacemembers.html":[5,1,0,19],
"namespacemembers.html":[5,1,0,23],
"namespacemembers.html":[5,1,0,18],
"namespacemembers.html":[5,1,0,22],
"namespacemembers_enum.html":[5,1,4],
"namespacemembers_eval.html":[5,1,5],
"namespacemembers_func.html":[5,1,1,14],
"namespacemembers_func.html":[5,1,1],
"namespacemembers_func.html":[5,1,1,0],
"namespacemembers_func.html":[5,1,1,1],
"namespacemembers_func.html":[5,1,1,2],
"namespacemembers_func.html":[5,1,1,3],
"namespacemembers_func.html":[5,1,1,4],
"namespacemembers_func.html":[5,1,1,5],
"namespacemembers_func.html":[5,1,1,6],
"namespacemembers_func.html":[5,1,1,7],
"namespacemembers_func.html":[5,1,1,9],
"namespacemembers_func.html":[5,1,1,8],
"namespacemembers_func.html":[5,1,1,10],
"namespacemembers_func.html":[5,1,1,11],
"namespacemembers_func.html":[5,1,1,12],
"namespacemembers_func.html":[5,1,1,13],
"namespacemembers_func.html":[5,1,1,15],
"namespacemembers_func.html":[5,1,1,16],
"namespacemembers_func.html":[5,1,1,17],
"namespacemembers_func.html":[5,1,1,18],
"namespacemembers_func.html":[5,1,1,19],
"namespacemembers_func.html":[5,1,1,20],
"namespacemembers_func.html":[5,1,1,21],
"namespacemembers_func.html":[5,1,1,22],
"namespacemembers_type.html":[5,1,3],
"namespacemembers_vars.html":[5,1,2],
"namespaces.html":[5,0],
"namespaceviennacl.html":[5,0,1],
"namespaceviennacl.html":[6,0,0],
"namespaceviennacl_1_1backend.html":[5,0,1,0],
"namespaceviennacl_1_1backend.html":[6,0,0,0],
"namespaceviennacl_1_1backend_1_1cpu__ram.html":[5,0,1,0,0],
"namespaceviennacl_1_1backend_1_1cpu__ram.html":[6,0,0,0,0],
"namespaceviennacl_1_1backend_1_1cpu__ram_1_1detail.html":[5,0,1,0,0,0],
"namespaceviennacl_1_1backend_1_1cpu__ram_1_1detail.html":[6,0,0,0,0,0],
"namespaceviennacl_1_1backend_1_1cuda.html":[6,0,0,0,1],
"namespaceviennacl_1_1backend_1_1cuda.html":[5,0,1,0,1],
"namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[5,0,1,0,1,0],
"namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[6,0,0,0,1,0],
"namespaceviennacl_1_1backend_1_1detail.html":[6,0,0,0,2],
"namespaceviennacl_1_1backend_1_1detail.html":[5,0,1,0,2],
"namespaceviennacl_1_1backend_1_1opencl.html":[6,0,0,0,3],
"namespaceviennacl_1_1backend_1_1opencl.html":[5,0,1,0,3],
"namespaceviennacl_1_1backend_1_1opencl_1_1detail.html":[5,0,1,0,3,0],
"namespaceviennacl_1_1detail.html":[6,0,0,1],
"namespaceviennacl_1_1detail.html":[5,0,1,1],
"namespaceviennacl_1_1detail_1_1fft.html":[5,0,1,1,0],
"namespaceviennacl_1_1detail_1_1fft.html":[6,0,0,1,0],
"namespaceviennacl_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,1,0,0],
"namespaceviennacl_1_1device__specific.html":[6,0,0,2],
"namespaceviennacl_1_1device__specific.html":[5,0,1,2],
"namespaceviennacl_1_1device__specific_1_1autotune.html":[5,0,1,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database.html":[5,0,1,2,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database.html":[6,0,0,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[5,0,1,2,1,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[6,0,0,2,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[6,0,0,2,0,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[5,0,1,2,1,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator_1_1fallback.html":[5,0,1,2,1,0,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[5,0,1,2,1,0,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[6,0,0,2,0,0,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu_1_1fallback.html":[5,0,1,2,1,0,1,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[5,0,1,2,1,0,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[6,0,0,2,0,0,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[5,0,1,2,1,0,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[6,0,0,2,0,0,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[5,0,1,2,1,0,2,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[6,0,0,2,0,0,2,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen_1_1cedar.html":[5,0,1,2,1,0,2,0,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen_1_1cypress.html":[5,0,1,2,1,0,2,0,0,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands.html":[5,0,1,2,1,0,2,0,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands.html":[6,0,0,2,0,0,2,0,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands_1_1barts.html":[5,0,1,2,1,0,2,0,1,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands_1_1devastator.html":[5,0,1,2,1,0,2,0,1,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands_1_1scrapper.html":[5,0,1,2,1,0,2,0,1,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[5,0,1,2,1,0,2,0,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[6,0,0,2,0,0,2,0,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands_1_1tahiti.html":[5,0,1,2,1,0,2,0,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[5,0,1,2,1,0,2,0,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[6,0,0,2,0,0,2,0,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands_1_1hawaii.html":[5,0,1,2,1,0,2,0,3,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1fallback.html":[5,0,1,2,1,0,2,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[5,0,1,2,1,0,2,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[6,0,0,2,0,0,2,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[5,0,1,2,1,0,2,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[6,0,0,2,0,0,2,1,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gt__540m.html":[5,0,1,2,1,0,2,2,0,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__470.html":[5,0,1,2,1,0,2,2,0,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__580.html":[5,0,1,2,1,0,2,2,0,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1tesla__c2050.html":[5,0,1,2,1,0,2,2,0,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[6,0,0,2,0,0,2,1,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[5,0,1,2,1,0,2,2,1],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler_1_1tesla__k20m.html":[5,0,1,2,1,0,2,2,1,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell.html":[5,0,1,2,1,0,2,2,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell.html":[6,0,0,2,0,0,2,1,2],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell_1_1geforce__gtx__750__ti.html":[5,0,1,2,1,0,2,2,2,0],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[5,0,1,2,1,0,2,2,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[6,0,0,2,0,0,2,1,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla_1_1geforce__gtx__260.html":[5,0,1,2,1,0,2,2,3,0],
"namespaceviennacl_1_1device__specific_1_1detail.html":[5,0,1,2,2],
"namespaceviennacl_1_1device__specific_1_1profiles.html":[5,0,1,2,3],
"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[5,0,1,2,4],
"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
"namespaceviennacl_1_1device__specific_1_1utils.html":[5,0,1,2,5],
"namespaceviennacl_1_1device__specific_1_1utils.html":[6,0,0,2,2],
"namespaceviennacl_1_1io.html":[5,0,1,3],
"namespaceviennacl_1_1io.html":[6,0,0,3],
"namespaceviennacl_1_1io_1_1detail.html":[5,0,1,3,0],
"namespaceviennacl_1_1io_1_1tag.html":[5,0,1,3,1],
"namespaceviennacl_1_1io_1_1val.html":[5,0,1,3,2],
"namespaceviennacl_1_1linalg.html":[5,0,1,4],
"namespaceviennacl_1_1linalg.html":[6,0,0,4],
"namespaceviennacl_1_1linalg_1_1cuda.html":[5,0,1,4,0],
"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[5,0,1,4,0,0],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[5,0,1,4,0,0,0],
"namespaceviennacl_1_1linalg_1_1detail.html":[6,0,0,4,1],
"namespaceviennacl_1_1linalg_1_1detail.html":[5,0,1,4,1],
"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[6,0,0,4,1,0],
"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[5,0,1,4,1,0],
"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[5,0,1,4,1,1],
"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[5,0,1,4,1,2],
"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[6,0,0,4,1,1],
"namespaceviennacl_1_1linalg_1_1host__based.html":[5,0,1,4,2],
"namespaceviennacl_1_1linalg_1_1host__based.html":[6,0,0,4,2],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[5,0,1,4,2,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[5,0,1,4,2,0,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[6,0,0,4,2,0,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,4,2,0,0,0],
"namespaceviennacl_1_1linalg_1_1kernels.html":[5,0,1,4,3],
"namespaceviennacl_1_1linalg_1_1opencl.html":[5,0,1,4,4],
"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3],
"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,0],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,1],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,1,0],
"namespaceviennacl_1_1ocl.html":[6,0,0,5],
"namespaceviennacl_1_1ocl.html":[5,0,1,5],
"namespaceviennacl_1_1result__of.html":[5,0,1,6],
"namespaceviennacl_1_1result__of.html":[6,0,0,6],
"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
"namespaceviennacl_1_1tools.html":[5,0,1,8],
"namespaceviennacl_1_1tools.html":[6,0,0,8],
"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
"namespaceviennacl_1_1traits.html":[5,0,1,9],
"namespaceviennacl_1_1traits.html":[6,0,0,9],
"nmf_8cpp-example.html":[8,21],
"nmf_8hpp.html":[7,0,3,4,26],
"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,26,0]
};
